@@ -41,7 +41,8 @@ $worksheet= '';
 $SHEET = '' ;
 $DIR = '';
 $doc_DIR = '';
-
+my @SECTIONS = qw(document part chapter section subsection subsubsection);
+#my @SECTIONS = ( document part entete frame subsection subsubsection );
 #TODO biblio dans un fichier spar si on a rencontr \begin{thebibliography} Non,
 # on n'a qu'a mettre cet environnement de type link
 #$doc_DIR=$ENV{'w_docdir'}; 
@@ -62,7 +63,8 @@ while ($_ = shift (@ARGV))
   elsif (/^--email=(.*)$/) { $email   = $1; }
   elsif (/^--worksheet=(.*)$/) { $worksheet   = $1; } 
   elsif (/^--tooltip_prompt=(.*)$/) { $tooltip_prompt = $1; }
-  elsif (/^--linkout=(.*)$/) { $linkout   = $1; } 
+  elsif (/^--linkout=(.*)$/) { $linkout = $1; }
+  elsif (/^--cut=(.*)$/) { @SECTIONS = split(',',$1) ;} 
   elsif (/^--help$/) {
    usage(); # includes --help !
     exit 1;
@@ -112,7 +114,7 @@ my @liste_env_tabular = ('tabular') ;
 my @liste_env_spec = ('equation', 'multline', 'latexonly',
   'pmatrix','smallmatrix', 'eqnarray', 'array', 'algorithmic', 'algorithm', 'align',
   'thebibliography', 'pspicture', 'picture', 'cases', 'gather',
-  'displaymath', 'math', 'center');
+  'displaymath', 'math', 'center', 'minipage', 'lstlisting');
   
 my @liste_com_spec = ('paragraph', 'href', 'url', 'exercise', 'doc') ; #je ne m'en sers pas encore 
 
@@ -176,9 +178,7 @@ my %hash = (
 my %hash_toc = ();
 
 my %prefixe = ( fold => 'F_' , link => 'L_' );
-my @SECTIONS = (
-  'document', 'part', 'chapter', 'section', 'subsection', 'subsubsection'
-);
+
 my %hash_secinv;
 for (my $i = 0; $i <= $#SECTIONS; $i++) { $hash_secinv{$SECTIONS[$i]} = $i; }
 
@@ -280,6 +280,8 @@ my $SEC_MIN_GLOBAL = 10; # = \infty
 my @cnt = (0) x ($#SECTIONS + 1);
 my ($secpattern) = join('|', @SECTIONS);
 $TEXT =~ s/\\begin\s*{($secpattern)\s*}/cnt_section($1,\@cnt)/eg;
+$TEXT =~ s/\[fragile\]//g;
+$TEXT =~ s/\s*\\frametitle//g;
 $TEXT =~ s/\\end\s*{\s*($secpattern)\s*}/<\/$1>/g;
 $TEXT =~ s/\\wimsentre{($secpattern)}/\\wimsentre$1/g;
 $TEXT =~ s/\\(wimsentre)?($secpattern)\b\*?/open_close($2,\@cnt,$1)/eg;
@@ -716,6 +718,39 @@ sub tabular { my ( $b, $style ) = @_;
  $b ; 
 }
 
+###demande de convertir d'abord de manire indpendante les pdf tiff eps svg en un format d'image png
+sub includegraphics{ my ( $b, $opt ) = @_;
+   $b=~ s/.(pdf|tiff|eps|svg)/.png/ ; 
+   $opt =~ s/.*(width|height)\s*=\s*([0-9]*\.?[0-9]*\s*)(\\(line|text)width)/linewidth("$2$3",$1)/eg;
+   $opt =~ s/.*(width|height)\s*=\s*([0-9]*\.?[0-9]*\s*)(cm|px)/$1=\"$2$3\"/;
+  "<img src=\"\\filedir\/$b\" $opt alt=\"\">";
+}
+ 
+sub minipage { my ( $b ) = @_; 
+ my @v = extract_bracketed ($b, '[]') ;
+ my $option = $v[0] ;  
+ $option=~ s/\[\s*b\s*\]/bottom/ ;  
+ $option=~ s/\[\s*t\s*\]/top/ ;
+ $option=~ s/\[\s*c\s*\]/middle/ ; 
+ $option=~s/\[\s*\]/middle/;
+ if (!$option) { $option='middle'} ;
+ @v = extract_bracketed ($v[1], '{}') ;
+ my $width = $v[0] ;
+ $width =~ s/\{(.*)\}/$1/;
+ $width = linewidth($width) ;
+  "<div style=\"width:$width; display:inline-block;vertical-align:$option;\" class=\"minipage\">
+   $v[1] 
+   </div>";
+}
+sub lstlisting { my ($b,$id ) = @_ ;
+  $b =~ s ,\\,\\\\,g ;
+  "<pre class=\"lstlisting\" id=\"lstlisting$id\">$b</pre>";
+}
+
+sub verbatim { my ($b,$id ) = @_ ;
+  $b =~ s ,\\,\\\\,g ;
+  "<pre class=\"verbatim\" id=\"verbatim$id\">$b</pre>";
+}
 
 sub multline { my ( $b) = @_;
   $b =~ s/\\\\\s*=/\\)<br>\\(== /g;
@@ -783,7 +818,7 @@ sub pspicture { '<p>dessin  faire dans wims</p>' ; }
 sub picture { '<p>dessin  faire dans wims</p>' ; }
 
 #decoupe ce qui se trouve  l'intrieur de \begin{wims} \end{wims} pour ne pas y toucher.
-#faire de mme pour verbatim
+# mme pour verbatim, lstlisting
 sub traite_special { my ( $TEXT, $ref_spec, $ref, $environ ) = @_;
   $TEXT = recup_embed($TEXT, $ref) ;
   $TEXT =~ s/\\begin{$environ}/<$environ>/g;
@@ -965,6 +1000,8 @@ sub find_expand { my ($file) = @_;
   $text =~ s/([^%])\s*\\endinput[[:print:][:space:]]+/$1/;
   $text =~ s/\%\\(input|include|wimsinclude)([^\n]+)?//g;
   $text =~ s/\\(input|include|wimsinclude)\s*{?([a-zA-Z0-9\-_\/]+)\.(sty|tex)\s*}?/find_expand("$2.$3")/eg;
+  $text =~ s/\\lstinputlisting\s*\{([a-zA-Z0-9\-_\/\.]+)\s*\}/"\\begin\{lstlisting\}\n" . find_expand($1) . "\n\\end\{lstlisting\}"/eg;
+ 
   $text;
 }
 
@@ -1021,10 +1058,11 @@ sub add { my ($a,$b)=@_ ;
 
 sub Init { my ($file, $ref_env, $ref_command, $ref, $ref_algo) = @_;
   my ($total, $TEXT) = (0, find_expand($file));
-  my %hash_spec = (wims =>{}, verbatim =>{});
+  my %hash_spec = (wims =>{}, verbatim =>{}, lstlisting => {});
   my $ref_spec = \%hash_spec;
   $TEXT = traite_special ($TEXT, $ref_spec->{wims}, $ref,'wims');
   $TEXT = traite_special ($TEXT, $ref_spec->{verbatim}, $ref,'verbatim');
+  $TEXT = traite_special ($TEXT, $ref_spec->{lstlisting}, $ref,'lstlisting');
   $TEXT = traitement_initial ($TEXT);
   $TEXT =~ s/\\wimsoption\s*\{([^\}]+)\}/store_option($1)/eg ;
   $TEXT =~ s/\\makeindex/store_option('index')/eg ;
@@ -1038,8 +1076,9 @@ sub Init { my ($file, $ref_env, $ref_command, $ref, $ref_algo) = @_;
   for my $A (@liste_voca) {
    $ref_algo->{titre}{$A} =  $ref_command->{definition}{"algorithmic\L$A\E"}  if ($ref_command->{definition}{"algorithmic\L$A\E"}) ;
 } ;
-  $TEXT =~ s/wimsinsertion(\d*)/$ref_spec->{wims}{$1}/g;
-  $TEXT =~ s/verbatiminsertion(\d*)/<pre class="verbatim">$ref_spec->{verbatim}{$1}<\/pre>/g;
+  $TEXT =~ s/wimsinsertion(\d*)/$ref_spec->{'wims'}{$1}/g;
+  $TEXT =~ s/verbatiminsertion(\d*)/verbatim($ref_spec->{'verbatim'}{$1},$1)/eg;
+  $TEXT =~ s/lstlistinginsertion(\d*)/lstlisting($ref_spec->{'lstlisting'}{$1},$1)/eg;
   $TEXT;
 }
 
@@ -1130,6 +1169,16 @@ sub traitement_initial { my ($TEXT) = @_;
   $TEXT =~ s/\\textquotesingle/'/g;
   $TEXT =~ s/\\guillemotleft/<</g;
   $TEXT =~ s/\\guillemotright/>>/g;
+# MODIF YVES NOEL 19/09/2011 (debut)
+  $TEXT =~ s/>>/&gt;&gt;/g;
+  $TEXT =~ s/~~/&nbsp;&nbsp;/g;
+  $TEXT =~ s/\\onslide\+<[0-9]*>//g;
+  $TEXT =~ s/\\onslide<[0-9]*->//g;
+  $TEXT =~ s/\\onslide<[0-9]*>//g;
+  $TEXT =~ s/\\onslide\+<[0-9]*\-[0-9]*>//g;
+  $TEXT =~ s/\\onslide<[0-9]*\-[0-9]*->//g;
+  $TEXT =~ s/\\onslide<[0-9]*\-[0-9]*>//g;
+# MODIF YVES NOEL 19/09/2011 (fin)
   $TEXT =~ s/{}//g;
   $TEXT =~ s/\\selectlanguage{french}\\sffamily//g;
   
@@ -1146,14 +1195,22 @@ sub traitement_initial { my ($TEXT) = @_;
   $TEXT =~ s/~(:|;|\?|\!)/&nbsp;$1/g;
  #utiliser verb uniquement dans le cas d'un mot
 #FIXME:  $TEXT =~ s/\verb"([^"]+)"/<tt class=verb>$1<\/tt>/g;
-  $TEXT =~ s/\\includegraphics\s*\[(.*)\]\s*{(.*)}/<img src=\"\\filedir\/$2\" $1 alt=\"\">/g;
-  $TEXT =~ s/\\includegraphics\s*{(.*)}/<img src=\"$1\" alt=\"\">/g;
+  $TEXT =~ s/\\includegraphics\s*\[(.*)\]\s*{(.*)}/includegraphics($2,$1)/eg;
+  $TEXT =~ s/\\includegraphics\s*{([^}]+)}/includegraphics($1)/eg;
   $TEXT =~ s/\\(begin|end){document}/\\document /g;
   $TEXT =~ s/\\exercise{module=([^\&]+)\&([^}]+)}{([^}]+)}/store_sheet($1,$2,$3,$worksheet)/eg ; 
   $TEXT =~ s/\\xspace//g;
   $TEXT;
 }
 
+sub linewidth { my ($line,$w)= @_ ;
+  $line =~ s/1\.[0]\s*\\(line|text)width/100\%/g;
+  $line =~ s/0?\.([0-9])\s*\\(line|text)width/$1 0\%/g;
+  $line =~ s/0?\.([0-9]{2})[0-9]?\s*\\(line|text)width/$1\%/g;
+  $line =~ s/ //g;
+  $line = "$w=\"$line\"" if ($w) ;
+  $line ; 
+}
 sub store_sheet { my ($ad1,$ad2,$titre,$worksheet) = @_ ;
    $ad2 =~ s/worksheet=(\d)+//g ; 
    $SHEET .= ":$ad1\n$ad2\n$titre\n\n" ;
@@ -1333,7 +1390,7 @@ sub store_tip { my ($tag,$ref)=@_ ;
   my $title=$ref->{tittoc}{$tag} ;
   $tip =~ s/'/\\\\'/g if ($tip) ; 
    $title =~ s/'/\\\\'/g if ($title) ; 
-  $ref->{toctip}{$tag} ?  "<a onmouseover=\"Tip('$tip',TITLE,'$title',TITLEBGCOLOR,'',width,'200px')\" onmouseout=\"UnTip()\">$tooltip_prompt<\/a>" : '' ; 
+  $ref->{toctip}{$tag} ?  "<a onmouseover=\"Tip('$tip',TITLE,'$title',TITLEBGCOLOR,'',WIDTH,'200px')\" onmouseout=\"UnTip()\">$tooltip_prompt<\/a>" : '' ; 
 }
 
 sub chemin { my ($tag, $ref) = @_;
